<?php
/**
 * Sauna Lite functions and definitions
 *
 * @package Sauna Lite
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

if ( ! function_exists( 'sauna_lite_setup' ) ) :

/* Theme Setup */
function sauna_lite_setup() {

	$GLOBALS['content_width'] = apply_filters( 'sauna_lite_content_width', 640 );
	
	load_theme_textdomain( 'sauna-lite', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('sauna-lite-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'sauna-lite' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	add_theme_support ('html5', array (
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ) );

	add_theme_support('responsive-embeds');
	
	/*
	* Enable support for Post Formats.
	*
	* See: https://codex.wordpress.org/Post_Formats
	*/
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/* Selective refresh for widgets */
	add_theme_support( 'customize-selective-refresh-widgets' );

	/* Starter Content */
	add_theme_support( 'starter-content', array(
		'widgets' => array(
			'sidebar-1' => array(
				'text_business_info',
				'search',
				'text_about',
			),
			'sidebar-2' => array(
				'text_business_info',
			),
			'sidebar-3' => array(
				'text_about',
				'search',
			),
			'footer-1' => array(
				'text_about',
			),
			'footer-2' => array(
				'archives',
			),
			'footer-3' => array(
				'text_business_info',
			),
			'footer-4' => array(
				'search',
			),
		),

		'posts' => array(
			'home',
			'about' => array(
				'thumbnail' => '{{image-espresso}}',
			),
			'contact' => array(
				'thumbnail' => '{{image-coffee}}',
			),
			'blog' => array(
				'thumbnail' => '{{image-coffee}}',
			),
		),

		'theme_mods' => array(
			'sauna_lite_footer_copy' => __('By ThemesCaliber', 'sauna-lite' )
		),

		'nav_menus' => array(
			'primary' => array(
				'name' => __( 'Primary Menu', 'sauna-lite' ),
				'items' => array(
					'page_home',
					'page_about',
					'page_blog',
					'page_contact',
				),
			),
		),
    ));

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	
	add_editor_style( array( 'css/editor-style.css', sauna_lite_font_url() ) );

	// Dashboard Theme Notification
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'sauna_lite_activation_notice' );
	}	
}
endif;
add_action( 'after_setup_theme', 'sauna_lite_setup' );

// Dashboard Theme Notification
function sauna_lite_activation_notice() {
	echo '<div class="welcome-notice notice notice-success is-dismissible">';
		echo '<h2>'. esc_html__( 'Thank You!!!!!', 'sauna-lite' ) .'</h2>';
		echo '<p>'. esc_html__( 'Much grateful to you for choosing our Sauna theme from themescaliber. we praise you for opting our services over others. we are obliged to invite you on our welcome page to render you with our outstanding services.', 'sauna-lite' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=sauna_lite_guide' ) ) .'" class="button button-primary">'. esc_html__( 'Click Here...', 'sauna-lite' ) .'</a></p>';
	echo '</div>';
}

/* Theme Widgets Setup */
function sauna_lite_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'sauna-lite' ),
		'description'   => __( 'Appears on blog page sidebar', 'sauna-lite' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s mb-4 p-2">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title mb-3">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'sauna-lite' ),
		'description'   => __( 'Appears on page sidebar', 'sauna-lite' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s mb-4 p-2">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title mb-3">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'sauna-lite' ),
		'description'   => __( 'Appears on page sidebar', 'sauna-lite' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s mb-4 p-2">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title mb-3">',
		'after_title'   => '</h3>',
	) );

	//Footer widget areas
	$sauna_lite_widget_areas = get_theme_mod('sauna_lite_footer_widget_layout', '4');
	for ($i=1; $i<=$sauna_lite_widget_areas; $i++) {
		register_sidebar( array(
			'name'          => __( 'Footer Nav ', 'sauna-lite' ) . $i,
			'id'            => 'footer-' . $i,
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s my-3">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title mb-2">',
			'after_title'   => '</h3>',
		) );
	}

}
add_action( 'widgets_init', 'sauna_lite_widgets_init' );

function sauna_lite_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'ABeeZee:400,400i';
	$font_family[] = 'PT Sans:400,400i,700,700i';
	$font_family[] = 'PT Serif:400,400i,700,700i';
	$font_family[] = 'Roboto:100,100i,300,300i,400,400i,500,500i,700,700i,900,900i';
	$font_family[] = 'Roboto Condensed:300,300i,400,400i,700,700i';
	$font_family[] = 'Open Sans:300,300i,400,400i,500,500i,600,600i,700,700i,800,800i';
	$font_family[] = 'Overpass:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Montserrat::100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Playball:400';
	$font_family[] = 'Alegreya:400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Julius Sans One';
	$font_family[] = 'Arsenal:400,400i,700,700i';
	$font_family[] = 'Slabo';
	$font_family[] = 'Lato:100,100i,300,300i,400,400i,700,700i,900,900i';
	$font_family[] = 'Overpass Mono:300,400,500,600,700';
	$font_family[] = 'Source Sans Pro:200,200i,300,300i,400,400i,600,600i,700,700i,900,900i';
	$font_family[] = 'Raleway:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Merriweather:300,300i,400,400i,700,700i,900,900i';
	$font_family[] = 'Droid Sans';
	$font_family[] = 'Rubik:300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Lora:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Ubuntu:300,300i,400,400i,500,500i,700,700i';
	$font_family[] = 'Cabin:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Arimo:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Playfair Display:400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Quicksand:400,400i,700,700i';
	$font_family[] = 'Padauk:400,700';
	$font_family[] = 'Muli';
	$font_family[] = 'Mulish:200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Inconsolata:200,300,400,500,600,700,800,900';
	$font_family[] = 'Bitter:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Pacifico';
	$font_family[] = 'Indie Flower';
	$font_family[] = 'VT323';
	$font_family[] = 'Dosis:200,300,400,500,600,700,800';
	$font_family[] = 'Frank Ruhl Libre:300,400,500,700,900';
	$font_family[] = 'Gabriela:400';
	$font_family[] = 'Fjalla One';
	$font_family[] = 'Oxygen:300,400,700';
	$font_family[] = 'Arvo:400,400i,700,700i';
	$font_family[] = 'Noto Serif:400,400i,700,700i';
	$font_family[] = 'Lobster';
	$font_family[] = 'Crimson Text:400,400i,600,600i,700,700i';
	$font_family[] = 'Yanone Kaffeesatz:200,300,400,500,600,700';
	$font_family[] = 'Anton';
	$font_family[] = 'Libre Baskerville:400,400i,700';
	$font_family[] = 'Bree Serif';
	$font_family[] = 'Gloria Hallelujah';
	$font_family[] = 'Josefin Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Jost:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Abril Fatface';
	$font_family[] = 'Varela Round';
	$font_family[] = 'Vampiro One';
	$font_family[] = 'Shadows Into Light';
	$font_family[] = 'Cuprum:400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Rokkitt:100,200,300,400,500,600,700,800,900';
	$font_family[] = 'Vollkorn:400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Francois One';
	$font_family[] = 'Orbitron:400,500,600,700,800,900';
	$font_family[] = 'Patua One';
	$font_family[] = 'Acme';
	$font_family[] = 'Allura:400';
	$font_family[] = 'Satisfy';
	$font_family[] = 'Josefin Slab:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Quattrocento Sans';
	$font_family[] = 'Architects Daughter';
	$font_family[] = 'Archivo:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Russo One';
	$font_family[] = 'Monda:400,700';
	$font_family[] = 'Righteous';
	$font_family[] = 'Saira:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Sen:400,700,800';
	$font_family[] = 'Lobster Two:400,400i,700,700i';
	$font_family[] = 'Hammersmith One';
	$font_family[] = 'Heebo:100,200,300,400,500,700,800,900';
	$font_family[] = 'Hind:300,400,500,600,700';
	$font_family[] = 'Courgette';
	$font_family[] = 'Permanent Marker';
	$font_family[] = 'Cherry Swash:400,700';
	$font_family[] = 'Cormorant Garamond:300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Poiret One';
	$font_family[] = 'Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'BenchNine:300,400,700';
	$font_family[] = 'Economica:400,400i,700,700i';
	$font_family[] = 'Fira Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Handlee';
	$font_family[] = 'Cardo:400,400i,700';
	$font_family[] = 'Alfa Slab One';
	$font_family[] = 'Averia Serif Libre:300,300i,400,400i,700,700i';
	$font_family[] = 'Cookie';
	$font_family[] = 'Chewy';
	$font_family[] = 'Great Vibes';
	$font_family[] = 'Coming Soon';
	$font_family[] = 'Philosopher:400,400i,700,700i';
	$font_family[] = 'Days One';
	$font_family[] = 'Kanit:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Krub:200,200i,300,300i,400,400i,500,500i,600,600i,700,700i';
	$font_family[] = 'Shrikhand';
	$font_family[] = 'Spartan:100,200,300,400,500,600,700,800,900';
	$font_family[] = 'Staatliches';
	$font_family[] = 'Tangerine:400,700';
	$font_family[] = 'Trirong:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'IM Fell English SC';
	$font_family[] = 'Boogaloo';
	$font_family[] = 'Bangers';
	$font_family[] = 'Fredoka One';
	$font_family[] = 'Bad Script';
	$font_family[] = 'Volkhov:400,400i,700,700i';
	$font_family[] = 'Work Sans:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
	$font_family[] = 'Shadows Into Light Two';
	$font_family[] = 'Marck Script';
	$font_family[] = 'Sacramento';
	$font_family[] = 'Unica One';
	$font_family[] = 'ZCOOL XiaoWei';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
	$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'sauna_lite_loop_columns');
if (!function_exists('sauna_lite_loop_columns')) {
	function sauna_lite_loop_columns() {
		$columns = get_theme_mod( 'sauna_lite_products_per_row', 3 );
		return $columns; // 3 products per row
	}
}

//Change number of products that are displayed per page (shop page)
add_filter( 'loop_shop_per_page', 'sauna_lite_shop_per_page', 9 );
function sauna_lite_shop_per_page( $cols ) {
  	$cols = get_theme_mod( 'sauna_lite_product_per_page', 9 );
	return $cols;
}

/**
 * Enqueue block editor style
 */
function sauna_lite_block_editor_styles() {
	wp_enqueue_style( 'sauna-lite-font', sauna_lite_font_url(), array() );
	wp_enqueue_style( 'sauna-lite-block-patterns-style-frontend', get_theme_file_uri('/css/block-frontend.css') );
    wp_enqueue_style( 'bootstrap-style', esc_url(get_template_directory_uri()).'/css/bootstrap.css' );
    wp_enqueue_style( 'font-awesome-css', esc_url(get_template_directory_uri()).'/css/fontawesome-all.css' );
}
add_action( 'enqueue_block_editor_assets', 'sauna_lite_block_editor_styles' );

function sauna_lite_sanitize_dropdown_pages( $page_id, $setting ) {
  // Ensure $input is an absolute integer.
  $page_id = absint( $page_id );
  // If $page_id is an ID of a published page, return it; otherwise, return the default.
  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}
	
/* Theme enqueue scripts */
function sauna_lite_scripts() {
	wp_enqueue_style( 'sauna-lite-font', sauna_lite_font_url(), array() );	
	wp_enqueue_style( 'sauna-lite-block-patterns-style-editor', get_theme_file_uri( '/css/block-frontend.css' ), false, '1.0', 'all' );
	wp_enqueue_style( 'bootstrap-css', esc_url(get_template_directory_uri()).'/css/bootstrap.css' );
	wp_enqueue_style( 'sauna-lite-basic-style', get_stylesheet_uri() );
	wp_style_add_data( 'sauna-lite-style', 'rtl', 'replace' );
	wp_enqueue_style( 'font-awesome-css', esc_url(get_template_directory_uri()).'/css/fontawesome-all.css' );
	wp_enqueue_style( 'sauna-lite-block-style', esc_url(get_template_directory_uri()).'/css/block-style.css' );	

	// Paragraph
    $sauna_lite_paragraph_color = get_theme_mod('sauna_lite_paragraph_color', '');
    $sauna_lite_paragraph_font_family = get_theme_mod('sauna_lite_paragraph_font_family', '');
    $sauna_lite_paragraph_font_size = get_theme_mod('sauna_lite_paragraph_font_size', '');
	// "a" tag
	$sauna_lite_atag_color = get_theme_mod('sauna_lite_atag_color', '');
    $sauna_lite_atag_font_family = get_theme_mod('sauna_lite_atag_font_family', '');
	// "li" tag
	$sauna_lite_li_color = get_theme_mod('sauna_lite_li_color', '');
    $sauna_lite_li_font_family = get_theme_mod('sauna_lite_li_font_family', '');
	// H1
	$sauna_lite_h1_color = get_theme_mod('sauna_lite_h1_color', '');
    $sauna_lite_h1_font_family = get_theme_mod('sauna_lite_h1_font_family', '');
    $sauna_lite_h1_font_size = get_theme_mod('sauna_lite_h1_font_size', '');
	// H2
	$sauna_lite_h2_color = get_theme_mod('sauna_lite_h2_color', '');
    $sauna_lite_h2_font_family = get_theme_mod('sauna_lite_h2_font_family', '');
    $sauna_lite_h2_font_size = get_theme_mod('sauna_lite_h2_font_size', '');
	// H3
	$sauna_lite_h3_color = get_theme_mod('sauna_lite_h3_color', '');
    $sauna_lite_h3_font_family = get_theme_mod('sauna_lite_h3_font_family', '');
    $sauna_lite_h3_font_size = get_theme_mod('sauna_lite_h3_font_size', '');
	// H4
	$sauna_lite_h4_color = get_theme_mod('sauna_lite_h4_color', '');
    $sauna_lite_h4_font_family = get_theme_mod('sauna_lite_h4_font_family', '');
    $sauna_lite_h4_font_size = get_theme_mod('sauna_lite_h4_font_size', '');
	// H5
	$sauna_lite_h5_color = get_theme_mod('sauna_lite_h5_color', '');
    $sauna_lite_h5_font_family = get_theme_mod('sauna_lite_h5_font_family', '');
    $sauna_lite_h5_font_size = get_theme_mod('sauna_lite_h5_font_size', '');
	// H6
	$sauna_lite_h6_color = get_theme_mod('sauna_lite_h6_color', '');
    $sauna_lite_h6_font_family = get_theme_mod('sauna_lite_h6_font_family', '');
    $sauna_lite_h6_font_size = get_theme_mod('sauna_lite_h6_font_size', '');
    $sauna_lite_theme_color_first = get_theme_mod('sauna_lite_theme_color_first', '');
    $sauna_lite_theme_color_second = get_theme_mod('sauna_lite_theme_color_second', '');

	$sauna_lite_custom_css ='
		p,span{
		    color:'.esc_attr($sauna_lite_paragraph_color).'!important;
		    font-family: '.esc_attr($sauna_lite_paragraph_font_family).'!important;
		    font-size: '.esc_attr($sauna_lite_paragraph_font_size).'!important;
		}
		a{
		    color:'.esc_attr($sauna_lite_atag_color).'!important;
		    font-family: '.esc_attr($sauna_lite_atag_font_family).';
		}
		li{
		    color:'.esc_attr($sauna_lite_li_color).'!important;
		    font-family: '.esc_attr($sauna_lite_li_font_family).';
		}
		h1{
		    color:'.esc_attr($sauna_lite_h1_color).'!important;
		    font-family: '.esc_attr($sauna_lite_h1_font_family).'!important;
		    font-size: '.esc_attr($sauna_lite_h1_font_size).'!important;
		}
		h2{
		    color:'.esc_attr($sauna_lite_h2_color).'!important;
		    font-family: '.esc_attr($sauna_lite_h2_font_family).'!important;
		    font-size: '.esc_attr($sauna_lite_h2_font_size).'!important;
		}
		h3{
		    color:'.esc_attr($sauna_lite_h3_color).'!important;
		    font-family: '.esc_attr($sauna_lite_h3_font_family).'!important;
		    font-size: '.esc_attr($sauna_lite_h3_font_size).'!important;
		}
		h4{
		    color:'.esc_attr($sauna_lite_h4_color).'!important;
		    font-family: '.esc_attr($sauna_lite_h4_font_family).'!important;
		    font-size: '.esc_attr($sauna_lite_h4_font_size).'!important;
		}
		h5{
		    color:'.esc_attr($sauna_lite_h5_color).'!important;
		    font-family: '.esc_attr($sauna_lite_h5_font_family).'!important;
		    font-size: '.esc_attr($sauna_lite_h5_font_size).'!important;
		}
		h6{
		    color:'.esc_attr($sauna_lite_h6_color).'!important;
		    font-family: '.esc_attr($sauna_lite_h6_font_family).'!important;
		    font-size: '.esc_attr($sauna_lite_h6_font_size).'!important;
		}

		a.button,.metabox,#header,.pagination .current, .page-links .current,.pagination span, .pagination a,.tags a:hover,.primary-navigation a:hover,.primary-navigation ul ul a, .fixed-header, .woocommerce-product-search button[type="submit"], .woocommerce .widget_price_filter .ui-slider .ui-slider-range, .woocommerce .widget_price_filter .ui-slider .ui-slider-handle, .pagination a:hover, .page-links a:hover, .related-posts .page-box .read-more, .more-btn a, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current{
		 	background-color:'.esc_attr($sauna_lite_theme_color_first).';
		}
		a.button,#comments a.comment-reply-link,.copyright, nav.woocommerce-MyAccount-navigation ul li, .woocommerce a.button, .woocommerce button.button, .woocommerce button.button.alt,.woocommerce a.button.alt,.woocommerce input.button.alt, .woocommerce span.onsale, #comments input[type="submit"].submit, #sidebar .tagcloud a:hover, .search-submit, #our-services .page-box .read-more{
		    background-color:'.esc_attr($sauna_lite_theme_color_first).'!important;
		}
		a,code,span.post-title,.tags a, .tags a:visited, .tags a:active,.service-content h4,.primary-navigation ul ul a:hover,.primary-navigation ul li a:hover.entry-content a, a.r_button, #sauna-footer .tagcloud a:hover, h2.woocommerce-loop-product__title, span.woocommerce-Price-amount.amount, .woocommerce ul.products li.product:hover h2.woocommerce-loop-product__title,.woocommerce ul.products li.product:hover span.woocommerce-Price-amount.amount, .woocommerce ul.products li.product:hover a.added_to_cart, p.woocommerce-result-count, .woocommerce div.product .product_title, .woocommerce #respond input#submit:hover,  .woocommerce input.button:hover, #sidebar h3, .woocommerce a,.service-content a, h3.widget-title a, #our-services .page-box h2 a, #slider .inner_carousel h1 a, .entry-content a, #content-ma a, #sidebar ul li li a:hover, #sauna-footer ul li a:hover, .metabox .entry-date a:hover,.metabox .entry-author a:hover, .scrollup, .service-btn a:hover, .primary-navigation ul ul a:hover, .primary-navigation ul li a:hover, #sidebar ul li a:hover{
		    color:'.esc_attr($sauna_lite_theme_color_first).';
		}
		.tags a, .tags a:visited, .tags a:active, #our-services .page-box h2, .primary-navigation ul ul, a.button, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current{
		    border-color:'.esc_attr($sauna_lite_theme_color_first).';
		}
		@media screen and (max-width: 720px){
			.page-template-custom-frontpage #header{
				background-color:'.esc_attr($sauna_lite_theme_color_first).';
			}
		}
		@media screen and (max-width: 1000px){
			.side-menu {
				background-color:'.esc_attr($sauna_lite_theme_color_first).' ;
			}
			.primary-navigation ul ul a:hover, .primary-navigation ul li a:hover{
				color:'.esc_attr($sauna_lite_theme_color_first).'!important;
			}
		}
		#our-services .page-box h2, .related-posts .page-box h3{
		    border-bottom-color:'.esc_attr($sauna_lite_theme_color_first).';
		}
		.box-image img{
		    border-top-color:'.esc_attr($sauna_lite_theme_color_first).'!important;
		}
		.search-submit{
		    border-color:'.esc_attr($sauna_lite_theme_color_first).'!important;
		}
		.hvr-sweep-to-right:before, #header .nav ul li:hover > ul{
		    background-color:'.esc_attr($sauna_lite_theme_color_second).'!important;
		}
		.service-btn a:hover{
		    color:'.esc_attr($sauna_lite_theme_color_second).'!important;
		}
		#sauna-footer {
		    background-color:'.esc_attr($sauna_lite_theme_color_second).';
		}
	';

	wp_add_inline_style( 'sauna-lite-basic-style',$sauna_lite_custom_css );

	require get_parent_theme_file_path( '/tc-style.php' );
	wp_add_inline_style( 'sauna-lite-basic-style',$sauna_lite_custom_css );

	wp_enqueue_script( 'bootstrap-js', esc_url(get_template_directory_uri()) . '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'sauna-lite-customscripts', esc_url(get_template_directory_uri()) . '/js/custom.js', array('jquery') );
	wp_enqueue_script( 'jquery-superfish', esc_url(get_template_directory_uri()) . '/js/jquery.superfish.js', array('jquery') ,'',true);
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'sauna_lite_scripts' );

//Theme Url
define('SAUNA_LITE_FREE_THEME_DOC',__('https://themescaliber.com/demo/doc/free-tc-sauna/', 'sauna-lite'));
define('SAUNA_LITE_SUPPORT',__('https://wordpress.org/support/theme/sauna-lite', 'sauna-lite'));
define('SAUNA_LITE_REVIEW',__('https://wordpress.org/support/theme/sauna-lite/reviews/', 'sauna-lite'));
define('SAUNA_LITE_BUY_NOW',__('https://www.themescaliber.com/themes/sauna-spa-wordpress-theme', 'sauna-lite'));
define('SAUNA_LITE_LIVE_DEMO',__('https://www.themescaliber.com/sauna-theme', 'sauna-lite'));
define('SAUNA_LITE_PRO_DOC',__('https://themescaliber.com/demo/doc/tc-sauna-pro/', 'sauna-lite'));
define('SAUNA_LITE_CREDIT',__('https://www.themescaliber.com/themes/wp-sauna-spa-wordpress-theme', 'sauna-lite'));

if ( ! function_exists( 'sauna_lite_credit' ) ) {
	function sauna_lite_credit(){
		echo "<a href=".esc_url(SAUNA_LITE_CREDIT)." target='_blank'>". esc_html__('Sauna WordPress Theme','sauna-lite'). "</a>";
	}
}

/*radio button sanitization*/
 function sauna_lite_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Excerpt Limit Begin */
function sauna_lite_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

function sauna_lite_sanitize_checkbox( $input ) {
	// Boolean check 
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function sauna_lite_sanitize_float( $input ) {
    return filter_var($input, FILTER_SANITIZE_NUMBER_FLOAT, FILTER_FLAG_ALLOW_FRACTION);
}

/** Posts navigation. */
if ( ! function_exists( 'sauna_lite_post_navigation' ) ) {
	function sauna_lite_post_navigation() {
		$sauna_lite_pagination_type = get_theme_mod( 'sauna_lite_post_navigation_type', 'numbers' );
		if ( $sauna_lite_pagination_type == 'numbers' ) {
			the_posts_pagination();
		} else {
			the_posts_navigation( array(
	            'prev_text'          => __( 'Previous page', 'sauna-lite' ),
	            'next_text'          => __( 'Next page', 'sauna-lite' ),
	            'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'sauna-lite' ) . ' </span>',
	        ) );
		}
	}
}

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Customizer additions. */
require get_template_directory() . '/inc/custom-header.php';

/* Implement the get started page */
require get_template_directory() . '/inc/dashboard/getstart.php';

/* Webfonts */
require get_template_directory() . '/wptt-webfont-loader.php';

/* Block Pattern */
require get_template_directory() . '/block-patterns.php';